require 'time'
require 'cve_crawler/cve_crawler'
require 'cve_crawler/cve_parser'

module CVE
  VERSION_MAJOR = 0
  VERSION_MINOR = 3
  VERSION_BUILD = 0
  VERSION = "#{VERSION_MAJOR}.#{VERSION_MINOR}.#{VERSION_BUILD}".freeze

  class Core
    def initialize(crawl_type='default', verify_cert=true, user_agent=nil, filters=nil)
      unless user_agent
        user_agent = create_user_agent
      end

      @crawler = Crawler.new(crawl_type, verify_cert, user_agent)
      @parser = Parser.new(filters)
    end

    attr_reader :crawler, :parser

    def fetch
      body = crawl.body
      parse(body)
    end

    def crawl
      @crawler.crawl
    end

    def parse(data)
      @parser.parse(data)
    end

    def create_user_agent
      'RubyCVECrawler/' + VERSION + ' (https://github.com/zarthus/ruby-cve-crawler)'
    end

    def inspect
      "<CVE::Core crawler=#{@crawler.inspect} parser=#{@parser.inspect}>"
    end
  end
end
